IC: Information Criterion for selecting the tuning parameter.

Description Usage Arguments Value References

View source: R/IC.R

Description

Information Criterion for a fitted LassoGEE object with the AIC, BIC, or GCV criteria.

Usage

1
IC(obj, criterion = c("BIC", "AIC", "GCV", "AICc", "EBIC"))

Arguments

obj

A fitted LassoGEE object.

criterion

The criterion by which to select the regularization parameter. One of "AIC", "BIC", "GCV", "AICc", or "EBIC"; default is "BIC".

Value

IC

The calculated model selection criteria

References

Gao, X., and Yi, G. Y. (2013). Simultaneous model selection and estimation for mean and association structures with clustered binary data. Stat, 2(1), 102-118.


LassoGEE documentation built on Nov. 8, 2020, 4:37 p.m.

Related to IC in LassoGEE...