print.LassoGEE: print a LassoGEE object

Description Usage Arguments Details References See Also

View source: R/print.LassoGEE.R

Description

Print a summary of the results of a LassoGEE model.

Usage

1
2
## S3 method for class 'LassoGEE'
print(x, digits = NULL, ...)

Arguments

x

fitted 'LassoGEE' object

digits

significant digits in printout

...

additional print arguments

Details

A summary of the cross-validated fit is produced. print.cv.LassoGEE(object) will print the summary includes Working Correlation and Returned Error Value.

References

Li, Y., Gao, X., and Xu, W. (2020). Statistical consistency for generalized estimating equation with L_1 regularization.

See Also

LassoGEE, and cv.LassoGEE methods.


LassoGEE documentation built on Nov. 8, 2020, 4:37 p.m.