Description Usage Arguments Value References
Information Criterion for a fitted LassoGEE object with the AIC, BIC, or GCV criteria.
1 |
obj |
A fitted LassoGEE object. |
criterion |
The criterion by which to select the regularization parameter. One of "AIC", "BIC", "GCV", "AICc", or "EBIC"; default is "BIC". |
IC |
The calculated model selection criteria |
Gao, X., and Yi, G. Y. (2013). Simultaneous model selection and estimation for mean and association structures with clustered binary data. Stat, 2(1), 102-118.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.