Description Usage Arguments Details References See Also
View source: R/print.LassoGEE.R
Print a summary of the results of a LassoGEE model.
1 2 |
x |
fitted 'LassoGEE' object |
digits |
significant digits in printout |
... |
additional print arguments |
A summary of the cross-validated fit is produced. print.cv.LassoGEE(object)
will print the summary includes Working Correlation and Returned Error Value.
Li, Y., Gao, X., and Xu, W. (2020). Statistical consistency for generalized estimating equation with L_1 regularization.
LassoGEE, and cv.LassoGEE methods.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.